import pyglet
from pyglet.window import key
import math

class DisplayNode:
    def __init__(self):
        self.verts = ()
        self.colors = ()
        self.pos = (0, 0)
        self.anchor = (0.5, 0.5)
        self.width = 100
        self.height = 100
        self.drawBoundingBox = False
        self.children = []
        self.boxColor = (255, 0, 0)
    
    def addChild(self, child):
        self.children.append(child)
    
    def getMinX(self):
        return self.pos[0] - self.anchor[0]*self.width

    def getMinY(self):
        return self.pos[1] - self.anchor[1]*self.height

    def getMaxX(self):
        return self.pos[0] - self.anchor[0]*self.width + self.width

    def getMaxY(self):
        return self.pos[1] - self.anchor[1]*self.height + self.height


    def draw(self):
        center = (self.pos[0]-self.anchor[0] * self.width, self.pos[1]-self.anchor[1] * self.height)
        pyglet.gl.glPushMatrix()
        #pyglet.gl.glTranslatef(self.anchor[0] * self.width, self.anchor[1] * self.height, 0)
        #pyglet.gl.glRotatef(45, 0, 0, 1)
        #pyglet.gl.glTranslatef(-self.anchor[0] * self.width, -self.anchor[1] * self.height, 0)
        pyglet.gl.glTranslatef(center[0],  center[1], 0)
        pyglet.graphics.draw(len(self.verts)/2, pyglet.gl.GL_QUADS, ('v2f', self.verts), ('c3B', self.colors)) 
        
        #draw boundingbox around the object
        if self.drawBoundingBox:
            points = (0, 0, self.width, 0, self.width, self.height, 0, self.height)
            pyglet.graphics.draw(len(points)/2, pyglet.gl.GL_LINE_LOOP, ('v2f', points), ('c3B', self.boxColor * (len(points)/2)))

        #draw the children
        for child in self.children:
            child.draw()

        pyglet.gl.glPopMatrix()
        


