from DisplayNode import *

class TimerDisplay(DisplayNode):
    def __init__(self, radius = 100, segments = 10):
        DisplayNode.__init__(self)
        self.duration = 10
        self.elapsed = 0
        self.thickness = 10
        dt = 2 * math.pi / segments
        self.width = 2 * radius
        self.height = 2 * radius
        self.isDone = False

        self.label = pyglet.text.Label(str(self.duration), font_name='Times New Roman',\
        font_size=90, x=self.width*self.anchor[0], y=self.height*self.anchor[1], anchor_x ='center', anchor_y = 'center')
        
        self.addChild(self.label)

        for i in xrange(segments):
            self.verts += ((radius-self.thickness) * math.cos(dt*i) + self.anchor[0]*self.width, \
                            (radius-self.thickness) * math.sin(dt*i) + self.anchor[1]*self.height)
            self.verts += (radius * math.cos(dt*i) + self.anchor[0]*self.width, radius * math.sin(dt*i) + self.anchor[1]*self.height)
            self.verts += (radius * math.cos(dt*(i+1)) + self.anchor[0]*self.width, radius * math.sin(dt*(i+1)) + self.anchor[1]*self.height)
            self.verts += ((radius-self.thickness) * math.cos(dt*(i+1)) + self.anchor[0]*self.width, \
                            (radius-self.thickness) * math.sin(dt*(i+1))+self.anchor[1]*self.height)
        self.colors = (128, 128, 128) * (len(self.verts)/2)

    def resetTimer(self):
        self.elapsed = 0
        self.isDone = False

    def update(self, dt):
        if not(self.isDone):
            self.elapsed += dt
            self.label.text = (str(self.duration - int(self.elapsed)))
            if self.elapsed >= self.duration:
                self.isDone = True


